{
  am_pm_abbreviated => [
    "\N{U+0caa}\N{U+0cc2}\N{U+0cb0}\N{U+0ccd}\N{U+0cb5}\N{U+0cbe}\N{U+0cb9}\N{U+0ccd}\N{U+0ca8}",
    "\N{U+0c85}\N{U+0caa}\N{U+0cb0}\N{U+0cbe}\N{U+0cb9}\N{U+0ccd}\N{U+0ca8}",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "d/M, E",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-one" => "'week' W 'of' MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "MMM d",
    MMdd => "dd-MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMM => "MM-y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d,y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'week' w 'of' Y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "kn-IN",
  date_format_full => "EEEE, MMMM d, y",
  date_format_long => "MMMM d, y",
  date_format_medium => "MMM d, y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+0cb8}\N{U+0ccb}\N{U+0cae}",
    "\N{U+0cae}\N{U+0c82}\N{U+0c97}\N{U+0cb3}",
    "\N{U+0cac}\N{U+0cc1}\N{U+0ca7}",
    "\N{U+0c97}\N{U+0cc1}\N{U+0cb0}\N{U+0cc1}",
    "\N{U+0cb6}\N{U+0cc1}\N{U+0c95}\N{U+0ccd}\N{U+0cb0}",
    "\N{U+0cb6}\N{U+0ca8}\N{U+0cbf}",
    "\N{U+0cad}\N{U+0cbe}\N{U+0ca8}\N{U+0cc1}",
  ],
  day_format_narrow => [
    "\N{U+0cb8}\N{U+0ccb}",
    "\N{U+0cae}\N{U+0c82}",
    "\N{U+0cac}\N{U+0cc1}",
    "\N{U+0c97}\N{U+0cc1}",
    "\N{U+0cb6}\N{U+0cc1}",
    "\N{U+0cb6}",
    "\N{U+0cad}\N{U+0cbe}",
  ],
  day_format_wide => [
    "\N{U+0cb8}\N{U+0ccb}\N{U+0cae}\N{U+0cb5}\N{U+0cbe}\N{U+0cb0}",
    "\N{U+0cae}\N{U+0c82}\N{U+0c97}\N{U+0cb3}\N{U+0cb5}\N{U+0cbe}\N{U+0cb0}",
    "\N{U+0cac}\N{U+0cc1}\N{U+0ca7}\N{U+0cb5}\N{U+0cbe}\N{U+0cb0}",
    "\N{U+0c97}\N{U+0cc1}\N{U+0cb0}\N{U+0cc1}\N{U+0cb5}\N{U+0cbe}\N{U+0cb0}",
    "\N{U+0cb6}\N{U+0cc1}\N{U+0c95}\N{U+0ccd}\N{U+0cb0}\N{U+0cb5}\N{U+0cbe}\N{U+0cb0}",
    "\N{U+0cb6}\N{U+0ca8}\N{U+0cbf}\N{U+0cb5}\N{U+0cbe}\N{U+0cb0}",
    "\N{U+0cad}\N{U+0cbe}\N{U+0ca8}\N{U+0cc1}\N{U+0cb5}\N{U+0cbe}\N{U+0cb0}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0cb8}\N{U+0ccb}\N{U+0cae}",
    "\N{U+0cae}\N{U+0c82}\N{U+0c97}\N{U+0cb3}",
    "\N{U+0cac}\N{U+0cc1}\N{U+0ca7}",
    "\N{U+0c97}\N{U+0cc1}\N{U+0cb0}\N{U+0cc1}",
    "\N{U+0cb6}\N{U+0cc1}\N{U+0c95}\N{U+0ccd}\N{U+0cb0}",
    "\N{U+0cb6}\N{U+0ca8}\N{U+0cbf}",
    "\N{U+0cad}\N{U+0cbe}\N{U+0ca8}\N{U+0cc1}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0cb8}\N{U+0ccb}",
    "\N{U+0cae}\N{U+0c82}",
    "\N{U+0cac}\N{U+0cc1}",
    "\N{U+0c97}\N{U+0cc1}",
    "\N{U+0cb6}\N{U+0cc1}",
    "\N{U+0cb6}",
    "\N{U+0cad}\N{U+0cbe}",
  ],
  day_stand_alone_wide => [
    "\N{U+0cb8}\N{U+0ccb}\N{U+0cae}\N{U+0cb5}\N{U+0cbe}\N{U+0cb0}",
    "\N{U+0cae}\N{U+0c82}\N{U+0c97}\N{U+0cb3}\N{U+0cb5}\N{U+0cbe}\N{U+0cb0}",
    "\N{U+0cac}\N{U+0cc1}\N{U+0ca7}\N{U+0cb5}\N{U+0cbe}\N{U+0cb0}",
    "\N{U+0c97}\N{U+0cc1}\N{U+0cb0}\N{U+0cc1}\N{U+0cb5}\N{U+0cbe}\N{U+0cb0}",
    "\N{U+0cb6}\N{U+0cc1}\N{U+0c95}\N{U+0ccd}\N{U+0cb0}\N{U+0cb5}\N{U+0cbe}\N{U+0cb0}",
    "\N{U+0cb6}\N{U+0ca8}\N{U+0cbf}\N{U+0cb5}\N{U+0cbe}\N{U+0cb0}",
    "\N{U+0cad}\N{U+0cbe}\N{U+0ca8}\N{U+0cc1}\N{U+0cb5}\N{U+0cbe}\N{U+0cb0}",
  ],
  era_abbreviated => [
    "\N{U+0c95}\N{U+0ccd}\N{U+0cb0}\N{U+0cbf}.\N{U+0caa}\N{U+0cc2}",
    "\N{U+0c95}\N{U+0ccd}\N{U+0cb0}\N{U+0cbf}.\N{U+0cb6}",
  ],
  era_narrow => [
    "\N{U+0c95}\N{U+0ccd}\N{U+0cb0}\N{U+0cbf}.\N{U+0caa}\N{U+0cc2}",
    "\N{U+0c95}\N{U+0ccd}\N{U+0cb0}\N{U+0cbf}.\N{U+0cb6}",
  ],
  era_wide => [
    "\N{U+0c95}\N{U+0ccd}\N{U+0cb0}\N{U+0cbf}\N{U+0cb8}\N{U+0ccd}\N{U+0ca4} \N{U+0caa}\N{U+0cc2}\N{U+0cb0}\N{U+0ccd}\N{U+0cb5}",
    "\N{U+0c95}\N{U+0ccd}\N{U+0cb0}\N{U+0cbf}\N{U+0cb8}\N{U+0ccd}\N{U+0ca4} \N{U+0cb6}\N{U+0c95}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%A %d %b %Y %I:%M:%S %p %Z",
  glibc_date_format => "%-d/%-m/%y",
  glibc_datetime_format => "%A %d %b %Y %I:%M:%S %p",
  glibc_time_12_format => "%I:%M:%S %p %Z",
  glibc_time_format => "%I:%M:%S %p %Z",
  language => "Kannada",
  month_format_abbreviated => [
    "\N{U+0c9c}\N{U+0ca8}\N{U+0cb5}\N{U+0cb0}\N{U+0cbf}",
    "\N{U+0cab}\N{U+0cc6}\N{U+0cac}\N{U+0ccd}\N{U+0cb0}\N{U+0cb5}\N{U+0cb0}\N{U+0cbf}",
    "\N{U+0cae}\N{U+0cbe}\N{U+0cb0}\N{U+0ccd}\N{U+0c9a}\N{U+0ccd}",
    "\N{U+0c8f}\N{U+0caa}\N{U+0ccd}\N{U+0cb0}\N{U+0cbf}",
    "\N{U+0cae}\N{U+0cc7}",
    "\N{U+0c9c}\N{U+0cc2}\N{U+0ca8}\N{U+0ccd}",
    "\N{U+0c9c}\N{U+0cc1}\N{U+0cb2}\N{U+0cc8}",
    "\N{U+0c86}\N{U+0c97}",
    "\N{U+0cb8}\N{U+0cc6}\N{U+0caa}\N{U+0ccd}\N{U+0c9f}\N{U+0cc6}\N{U+0c82}",
    "\N{U+0c85}\N{U+0c95}\N{U+0ccd}\N{U+0c9f}\N{U+0ccb}",
    "\N{U+0ca8}\N{U+0cb5}\N{U+0cc6}\N{U+0c82}",
    "\N{U+0ca1}\N{U+0cbf}\N{U+0cb8}\N{U+0cc6}\N{U+0c82}",
  ],
  month_format_narrow => [
    "\N{U+0c9c}",
    "\N{U+0cab}\N{U+0cc6}",
    "\N{U+0cae}\N{U+0cbe}",
    "\N{U+0c8f}",
    "\N{U+0cae}\N{U+0cc7}",
    "\N{U+0c9c}\N{U+0cc2}",
    "\N{U+0c9c}\N{U+0cc1}",
    "\N{U+0c86}",
    "\N{U+0cb8}\N{U+0cc6}",
    "\N{U+0c85}",
    "\N{U+0ca8}",
    "\N{U+0ca1}\N{U+0cbf}",
  ],
  month_format_wide => [
    "\N{U+0c9c}\N{U+0ca8}\N{U+0cb5}\N{U+0cb0}\N{U+0cbf}",
    "\N{U+0cab}\N{U+0cc6}\N{U+0cac}\N{U+0ccd}\N{U+0cb0}\N{U+0cb5}\N{U+0cb0}\N{U+0cbf}",
    "\N{U+0cae}\N{U+0cbe}\N{U+0cb0}\N{U+0ccd}\N{U+0c9a}\N{U+0ccd}",
    "\N{U+0c8f}\N{U+0caa}\N{U+0ccd}\N{U+0cb0}\N{U+0cbf}\N{U+0cb2}\N{U+0ccd}",
    "\N{U+0cae}\N{U+0cc7}",
    "\N{U+0c9c}\N{U+0cc2}\N{U+0ca8}\N{U+0ccd}",
    "\N{U+0c9c}\N{U+0cc1}\N{U+0cb2}\N{U+0cc8}",
    "\N{U+0c86}\N{U+0c97}\N{U+0cb8}\N{U+0ccd}\N{U+0c9f}\N{U+0ccd}",
    "\N{U+0cb8}\N{U+0cc6}\N{U+0caa}\N{U+0ccd}\N{U+0c9f}\N{U+0cc6}\N{U+0c82}\N{U+0cac}\N{U+0cb0}\N{U+0ccd}",
    "\N{U+0c85}\N{U+0c95}\N{U+0ccd}\N{U+0c9f}\N{U+0ccb}\N{U+0cac}\N{U+0cb0}\N{U+0ccd}",
    "\N{U+0ca8}\N{U+0cb5}\N{U+0cc6}\N{U+0c82}\N{U+0cac}\N{U+0cb0}\N{U+0ccd}",
    "\N{U+0ca1}\N{U+0cbf}\N{U+0cb8}\N{U+0cc6}\N{U+0c82}\N{U+0cac}\N{U+0cb0}\N{U+0ccd}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+0c9c}\N{U+0ca8}",
    "\N{U+0cab}\N{U+0cc6}\N{U+0cac}\N{U+0ccd}\N{U+0cb0}",
    "\N{U+0cae}\N{U+0cbe}\N{U+0cb0}\N{U+0ccd}\N{U+0c9a}\N{U+0ccd}",
    "\N{U+0c8f}\N{U+0caa}\N{U+0ccd}\N{U+0cb0}\N{U+0cbf}",
    "\N{U+0cae}\N{U+0cc7}",
    "\N{U+0c9c}\N{U+0cc2}\N{U+0ca8}\N{U+0ccd}",
    "\N{U+0c9c}\N{U+0cc1}\N{U+0cb2}\N{U+0cc8}",
    "\N{U+0c86}\N{U+0c97}",
    "\N{U+0cb8}\N{U+0cc6}\N{U+0caa}\N{U+0ccd}\N{U+0c9f}\N{U+0cc6}\N{U+0c82}",
    "\N{U+0c85}\N{U+0c95}\N{U+0ccd}\N{U+0c9f}\N{U+0ccb}",
    "\N{U+0ca8}\N{U+0cb5}\N{U+0cc6}\N{U+0c82}",
    "\N{U+0ca1}\N{U+0cbf}\N{U+0cb8}\N{U+0cc6}\N{U+0c82}",
  ],
  month_stand_alone_narrow => [
    "\N{U+0c9c}",
    "\N{U+0cab}\N{U+0cc6}",
    "\N{U+0cae}\N{U+0cbe}",
    "\N{U+0c8f}",
    "\N{U+0cae}\N{U+0cc7}",
    "\N{U+0c9c}\N{U+0cc2}",
    "\N{U+0c9c}\N{U+0cc1}",
    "\N{U+0c86}",
    "\N{U+0cb8}\N{U+0cc6}",
    "\N{U+0c85}",
    "\N{U+0ca8}",
    "\N{U+0ca1}\N{U+0cbf}",
  ],
  month_stand_alone_wide => [
    "\N{U+0c9c}\N{U+0ca8}\N{U+0cb5}\N{U+0cb0}\N{U+0cbf}",
    "\N{U+0cab}\N{U+0cc6}\N{U+0cac}\N{U+0ccd}\N{U+0cb0}\N{U+0cb5}\N{U+0cb0}\N{U+0cbf}",
    "\N{U+0cae}\N{U+0cbe}\N{U+0cb0}\N{U+0ccd}\N{U+0c9a}\N{U+0ccd}",
    "\N{U+0c8f}\N{U+0caa}\N{U+0ccd}\N{U+0cb0}\N{U+0cbf}\N{U+0cb2}\N{U+0ccd}",
    "\N{U+0cae}\N{U+0cc7}",
    "\N{U+0c9c}\N{U+0cc2}\N{U+0ca8}\N{U+0ccd}",
    "\N{U+0c9c}\N{U+0cc1}\N{U+0cb2}\N{U+0cc8}",
    "\N{U+0c86}\N{U+0c97}\N{U+0cb8}\N{U+0ccd}\N{U+0c9f}\N{U+0ccd}",
    "\N{U+0cb8}\N{U+0cc6}\N{U+0caa}\N{U+0ccd}\N{U+0c9f}\N{U+0cc6}\N{U+0c82}\N{U+0cac}\N{U+0cb0}\N{U+0ccd}",
    "\N{U+0c85}\N{U+0c95}\N{U+0ccd}\N{U+0c9f}\N{U+0ccb}\N{U+0cac}\N{U+0cb0}\N{U+0ccd}",
    "\N{U+0ca8}\N{U+0cb5}\N{U+0cc6}\N{U+0c82}\N{U+0cac}\N{U+0cb0}\N{U+0ccd}",
    "\N{U+0ca1}\N{U+0cbf}\N{U+0cb8}\N{U+0cc6}\N{U+0c82}\N{U+0cac}\N{U+0cb0}\N{U+0ccd}",
  ],
  name => "Kannada India",
  native_language => "\N{U+0c95}\N{U+0ca8}\N{U+0ccd}\N{U+0ca8}\N{U+0ca1}",
  native_name => "\N{U+0c95}\N{U+0ca8}\N{U+0ccd}\N{U+0ca8}\N{U+0ca1} \N{U+0cad}\N{U+0cbe}\N{U+0cb0}\N{U+0ca4}",
  native_script => undef,
  native_territory => "\N{U+0cad}\N{U+0cbe}\N{U+0cb0}\N{U+0ca4}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+0ca4}\N{U+0ccd}\N{U+0cb0}\N{U+0cc8} 1",
    "\N{U+0ca4}\N{U+0ccd}\N{U+0cb0}\N{U+0cc8} 2",
    "\N{U+0ca4}\N{U+0ccd}\N{U+0cb0}\N{U+0cc8} 3",
    "\N{U+0ca4}\N{U+0ccd}\N{U+0cb0}\N{U+0cc8} 4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1\N{U+0ca8}\N{U+0cc7} \N{U+0ca4}\N{U+0ccd}\N{U+0cb0}\N{U+0cc8}\N{U+0cae}\N{U+0cbe}\N{U+0cb8}\N{U+0cbf}\N{U+0c95}",
    "2\N{U+0ca8}\N{U+0cc7} \N{U+0ca4}\N{U+0ccd}\N{U+0cb0}\N{U+0cc8}\N{U+0cae}\N{U+0cbe}\N{U+0cb8}\N{U+0cbf}\N{U+0c95}",
    "3\N{U+0ca8}\N{U+0cc7} \N{U+0ca4}\N{U+0ccd}\N{U+0cb0}\N{U+0cc8}\N{U+0cae}\N{U+0cbe}\N{U+0cb8}\N{U+0cbf}\N{U+0c95}",
    "4\N{U+0ca8}\N{U+0cc7} \N{U+0ca4}\N{U+0ccd}\N{U+0cb0}\N{U+0cc8}\N{U+0cae}\N{U+0cbe}\N{U+0cb8}\N{U+0cbf}\N{U+0c95}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+0ca4}\N{U+0ccd}\N{U+0cb0}\N{U+0cc8} 1",
    "\N{U+0ca4}\N{U+0ccd}\N{U+0cb0}\N{U+0cc8} 2",
    "\N{U+0ca4}\N{U+0ccd}\N{U+0cb0}\N{U+0cc8} 3",
    "\N{U+0ca4}\N{U+0ccd}\N{U+0cb0}\N{U+0cc8} 4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1\N{U+0ca8}\N{U+0cc7} \N{U+0ca4}\N{U+0ccd}\N{U+0cb0}\N{U+0cc8}\N{U+0cae}\N{U+0cbe}\N{U+0cb8}\N{U+0cbf}\N{U+0c95}",
    "2\N{U+0ca8}\N{U+0cc7} \N{U+0ca4}\N{U+0ccd}\N{U+0cb0}\N{U+0cc8}\N{U+0cae}\N{U+0cbe}\N{U+0cb8}\N{U+0cbf}\N{U+0c95}",
    "3\N{U+0ca8}\N{U+0cc7} \N{U+0ca4}\N{U+0ccd}\N{U+0cb0}\N{U+0cc8}\N{U+0cae}\N{U+0cbe}\N{U+0cb8}\N{U+0cbf}\N{U+0c95}",
    "4\N{U+0ca8}\N{U+0cc7} \N{U+0ca4}\N{U+0ccd}\N{U+0cb0}\N{U+0cc8}\N{U+0cae}\N{U+0cbe}\N{U+0cb8}\N{U+0cbf}\N{U+0c95}",
  ],
  script => undef,
  territory => "India",
  time_format_full => "hh:mm:ss a zzzz",
  time_format_long => "hh:mm:ss a z",
  time_format_medium => "hh:mm:ss a",
  time_format_short => "hh:mm a",
  variant => undef,
  version => 41,
}
